@@ -1,6 +1,6 @@
 package Statocles::Base;
 # ABSTRACT: Base module for Statocles modules
-$Statocles::Base::VERSION = '0.039';
+$Statocles::Base::VERSION = '0.040';
 use strict;
 use warnings;
 use base 'Import::Base';
@@ -49,6 +49,14 @@ our %IMPORT_BUNDLES = (
         @class_modules,
     ],
 
+    Emitter => [
+        'Statocles::Event',
+        sub {
+            my ( $bundles, $args ) = @_;
+            Moo::Role->apply_role_to_package( $args->{package}, 'Beam::Emitter' );
+            return;
+        },
+    ],
 );
 
 1;
@@ -63,7 +71,7 @@ Statocles::Base - Base module for Statocles modules
 
 =head1 VERSION
 
-version 0.039
+version 0.040
 
 =head1 SYNOPSIS
 
