@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.039';
+$Statocles::Command::VERSION = '0.040';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -133,6 +133,12 @@ sub main {
     }
     else {
         my $app_name = $method;
+        my $app = $cmd->site->apps->{ $app_name };
+
+        if ( !$app ) {
+            return pod2usage("ERROR: Unknown command or app '$app_name'");
+        }
+
         return $cmd->site->apps->{ $app_name }->command( @argv );
     }
 
@@ -197,6 +203,9 @@ sub create_site {
     }
 
     ### Build the site
+    my $cwd = cwd;
+    my $root = Path::Tiny->new( '.' );
+    chdir $root;
     my ( $site ) = YAML::Load( $create_dir->child( 'site.yml' )->slurp_utf8 );
 
     if ( $answer{flavor} == 1 ) {
@@ -216,6 +225,13 @@ sub create_site {
     if ( $answer{deploy_class} == 1 ) {
         $site->{deploy}{class} = 'Statocles::Deploy::Git';
         $site->{deploy}{args}{branch} = $answer{git_branch};
+
+        # Create the git repo
+        require Git::Repository;
+        # Running init more than once is apparently completely safe, so we don't
+        # even have to check before we run it
+        Git::Repository->run( 'init' );
+        $root->child( '.gitignore' )->append( "\n.statocles\n" );
     }
     elsif ( $answer{deploy_class} == 2 ) {
         $site->{deploy}{class} = 'Statocles::Deploy::File';
@@ -227,10 +243,19 @@ sub create_site {
         $site->{deploy}{args}{path} = '.';
     }
 
-    Path::Tiny->new( '.' )->child( 'site.yml' )->spew_utf8( YAML::Dump( $site ) );
+    $root->child( 'site.yml' )->spew_utf8( YAML::Dump( $site ) );
+
+    # Make required store directories
+    for my $app ( map { $_->{'$ref'} } values %{ $site->{site}{args}{apps} } ) {
+        my $path = $site->{$app}{args}{store};
+        next unless $path;
+        $root->child( $path )->mkpath;
+    }
 
     ### DONE!
     print "\n", "\n", $question->{finish}, "\n", "\n";
+    chdir $cwd;
+
     return 0;
 }
 
@@ -329,16 +354,14 @@ sub bundle_theme {
 
                     my $rebuild;
                     REBUILD:
-                    while ( $reactor->is_readable( $handle ) ) {
-                        for my $event ( $fs->read_events ) {
-                            if ( $event->path =~ /^\Q$build_dir/ ) {
-                                next;
-                            }
-
-                            $self->log->info( "Path '" . $event->path . "' changed... Rebuilding" );
-                            $_->clear for @{ $watches{ $path } };
-                            $rebuild = 1;
+                    for my $event ( $fs->read_events ) {
+                        if ( $event->path =~ /^\Q$build_dir/ ) {
+                            next;
                         }
+
+                        $self->log->info( "Path '" . $event->path . "' changed... Rebuilding" );
+                        $_->clear for @{ $watches{ $path } };
+                        $rebuild = 1;
                     }
 
                     if ( $rebuild ) {
@@ -402,7 +425,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.039
+version 0.040
 
 =head1 SYNOPSIS
 
