@@ -1,11 +1,13 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.039';
-use Statocles::Base 'Class';
+$Statocles::Site::VERSION = '0.040';
+use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Mojo::URL;
 use Mojo::DOM;
 use Mojo::Log;
+use Statocles::Page::Plain;
+use Statocles::Page::File;
 
 
 has title => (
@@ -17,6 +19,7 @@ has title => (
 has base_url => (
     is => 'ro',
     isa => Str,
+    default => sub { '/' },
 );
 
 
@@ -57,10 +60,10 @@ has build_store => (
     is => 'ro',
     isa => Store,
     default => sub {
-        my $path = '.statocles-build';
-        if ( !-d $path ) {
+        my $path = Path::Tiny->new( '.statocles', 'build' );
+        if ( !$path->is_dir ) {
             # Automatically make the build directory
-            mkdir $path;
+            $path->mkpath;
         }
         return Store->coercion->( $path );
     },
@@ -68,7 +71,7 @@ has build_store => (
         my ( $arg ) = @_;
         if ( !ref $arg && !-d $arg ) {
             # Automatically make the build directory
-            mkdir $arg;
+            Path::Tiny->new( $arg )->mkpath;
         }
         return Store->coercion->( $arg );
     },
@@ -141,6 +144,10 @@ sub build {
     my ( $self ) = @_;
 
     my $store = $self->build_store;
+
+    # Remove all pages from the build directory first
+    $_->remove_tree for $store->path->children;
+
     my $apps = $self->apps;
     my @pages;
     my %args = (
@@ -171,6 +178,7 @@ sub build {
         $base_url = $self->_write_deploy->base_url || $base_url;
     }
     my $base_path = Mojo::URL->new( $base_url )->path;
+    $base_path =~ s{/$}{};
 
     for my $page ( @pages ) {
         my $content = $page->render( %args );
@@ -196,19 +204,37 @@ sub build {
     # html files only
     my @indexed_pages = grep { $_->path =~ /[.]html?$/ } @pages;
     my $tmpl = $self->theme->template( site => 'sitemap.xml' );
-    $store->write_file( 'sitemap.xml', $tmpl->render( site => $self, pages => \@indexed_pages ) );
+    my $sitemap = Statocles::Page::Plain->new(
+        path => '/sitemap.xml',
+        content => $tmpl->render( site => $self, pages => \@indexed_pages ),
+    );
+    push @pages, $sitemap;
+    $store->write_file( 'sitemap.xml', $sitemap->render );
 
     # robots.txt is the best way for crawlers to automatically discover sitemap.xml
     # We should do more with this later...
     my $robots_tmpl = $self->theme->template( site => 'robots.txt' );
-    $store->write_file( 'robots.txt', $robots_tmpl->render( site => $self ) );
+    my $robots = Statocles::Page::Plain->new(
+        path => '/robots.txt',
+        content => $robots_tmpl->render( site => $self ),
+    );
+    push @pages, $robots;
+    $store->write_file( 'robots.txt', $robots->render );
 
     # Add the theme
     my $theme_iter = $self->theme->store->find_files();
     while ( my $theme_file = $theme_iter->() ) {
         my $fh = $self->theme->store->open_file( $theme_file );
+        push @pages, Statocles::Page::File->new(
+            path => join( '/', '', 'theme', $theme_file ),
+            fh => $fh,
+        );
         $store->write_file( Path::Tiny->new( 'theme', $theme_file ), $fh );
     }
+
+    $self->emit( build => class => 'Statocles::Event::Pages', pages => \@pages );
+
+    return;
 }
 
 
@@ -249,7 +275,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.039
+version 0.040
 
 =head1 SYNOPSIS
 
@@ -362,7 +388,7 @@ If the named nav does not exist, returns an empty list.
 
 =head2 build
 
-Build the site in its build location
+Build the site in its build location.
 
 =head2 deploy
 
@@ -372,6 +398,19 @@ Deploy the site to its destination.
 
 Get the full URL to the given path by prepending the C<base_url>.
 
+=head1 EVENTS
+
+The site object exposes the following events.
+
+=head2 build
+
+This event is fired after the site has been built and the pages written to the
+C<build_store>.
+
+The event will be a
+L<Statocles::Event::Pages|Statocles::Event/Statocles::Event::Pages> object
+containing all the pages built by the site.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
