@@ -1,6 +1,6 @@
 package Statocles::Template;
 # ABSTRACT: A template object to pass around
-$Statocles::Template::VERSION = '0.039';
+$Statocles::Template::VERSION = '0.040';
 use Statocles::Base 'Class';
 use Mojo::Template;
 use Scalar::Util qw( blessed );
@@ -84,7 +84,7 @@ sub render {
 sub _prelude {
     my ( $self, @vars ) = @_;
     return join " ",
-        'use strict; use warnings;',
+        'use strict; use warnings; no warnings "ambiguous";',
         'my $vars = shift;',
         map( { "my \$$_ = \$vars->{'$_'};" } @vars ),
         ;
@@ -139,7 +139,7 @@ Statocles::Template - A template object to pass around
 
 =head1 VERSION
 
-version 0.039
+version 0.040
 
 =head1 DESCRIPTION
 
