@@ -1,6 +1,6 @@
 package Statocles::Test;
 # ABSTRACT: Common test routines for Statocles
-$Statocles::Test::VERSION = '0.039';
+$Statocles::Test::VERSION = '0.040';
 use Statocles::Base;
 use Test::More;
 use Test::Exception;
@@ -32,7 +32,6 @@ sub build_test_site {
 
     return Statocles::Site->new(
         title => 'Example Site',
-        base_url => 'http://example.com/',
         build_store => $store,
         deploy => $deploy,
         %site_args,
@@ -244,7 +243,6 @@ sub build_temp_site {
         site => {
             class => 'Statocles::Site',
             args => {
-                base_url => 'http://example.com',
                 title => 'Site Title',
                 index => 'blog',
                 build_store => { '$ref' => 'build' },
@@ -274,7 +272,6 @@ sub build_temp_site {
         site_foo => {
             class => 'Statocles::Site',
             args => {
-                base_url => 'http://example.net',
                 title => 'Site Foo',
                 index => 'blog',
                 build_store => { '$ref' => 'build_foo' },
@@ -305,7 +302,7 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.039
+version 0.040
 
 =head1 DESCRIPTION
 
